@@ -6,7 +6,7 @@
 #define QT_FEATURE_avx2 -1
 #define QT_FEATURE_private_tests -1
 #define QT_FEATURE_dbus 1
-#define QT_FEATURE_dbus_linked 1
+#define QT_FEATURE_dbus_linked -1
 #define QT_FEATURE_dlopen -1
 #define QT_FEATURE_gc_binaries 1
 #define QT_FEATURE_gui 1
